
```
📁 Docs/
│    ├── 📁 Core/
│    │    ├── 📖 Core.md
│    │    ├── 📖 CoreCompany.md
│    ├── 📁 Destilation/
│    │    ├── 📖 DestilationAgents.md
│    ├── 📁 Moderation/
│    │    ├── 📖 RemoveWords.md
│    ├── 📁 Roadmaps/
│    │    ├── 📖 SoftwareAI-Roadmap.md
│    │    ├── 📖 Chat-Roadmap.md
│    │    ├── 📖 Editor-Roadmap.md
│    ├── 📁 ToolsAndFunctions/
│    │    ├── 📖 doc-tools.md
│    ├── 📁 Update/
│    │    ├── 📖 Update.md

📁 Examples/
    └── 🐍 exemple_1.py
📁 Flowchart/
    └── 🗺️ Fluxogram beta v 0.1.8.pdf

📁 CoreUi/
│    ├── 📁 ChatSoftwareAI/
│    │       ├── 📁 Chat/
│    │       │    └── 🐍 AIQthread.py
│    │       │    └── 🐍 Message_Reeceive.py
│    │       ├── 📁 generated-files/
│    │       │      ├── 📁 css/
│    │       │      │    └── 🎨 main.css
│    │       │      ├── 📁 json/
│    │       │      │    └── 🛠️ cliente_and_chat.json
│    │       │      │    └── 🛠️ interface.json
│    │       │      ├── 📁 ui/
│    │       │      │    └── ✨ new_cliente_and_chat.ui
│    │       │      │    └── ✨ new_interface.ui
│    │       ├── 📁 JsonStyle/
│    │       │      └── 🛠️ style.json
│    │       ├── 📁 logs/
│    │       │      └── 🔍 custom_widgets.log
│    │       ├── 📁 Qss/
│    │       │      ├── 📁 icons/
│    │       │      │    └── 📦 _icons.qrc
│    │       │      │    ├── 📁 icons/
│    │       │      │    │   ├── 📁 feather/
│    │       │      │    │   │   └── 🖼️ icons.png
│    │       │      │    │   ├── 📁 font_awesome/
│    │       │      │    │   │      └── 🖼️ icons.png
│    │       │      │    │   ├── 📁 material_design/
│    │       │      │    │   │      └── 🖼️ icons.png
│    │       │      │    ├── 📁 03C3C3/
│    │       │      │    │   ├── 📁 feather/
│    │       │      │    │   │   └── 🖼️ icons.png
│    │       │      │    │   ├── 📁 font_awesome/
│    │       │      │    │   │      └── 🖼️ icons.png
│    │       │      │    │   ├── 📁 material_design/
│    │       │      │    │   │      └── 🖼️ icons.png
│    │       │      ├── 📁 scss/
│    │       │      │    └── ✂️ _styles.scss
│    │       │      │    └── ✂️ _variables.scss
│    │       │      │    └── ✂️ defaultStyle.scss
│    │       │      │    └── ✂️ main.scss
│    │       ├── 📁 src_/
│    │       │    └── 🐍 icons_interpreter.py
│    │       │    └── 🐍 ui_cliente_and_chat.py
│    │       │    └── 🐍 ui_interface.py
│    │       ├── 📁 ui/
│    │       │    └── 🎨 cliente_and_chat.ui
│    │       │    └── 🎨 interface.ui
│    │       │
│    │       └── 🐍 Convert.py
│    │       └── 🐍 main.py
│    │    
│    ├── 📁 Editor/
│    │       ├── 📁 generated-files/
│    │       │      ├── 📁 css/
│    │       │      │    └── 🎨 main.css
│    │       │      ├── 📁 json/
│    │       │      │    └── 🛠️ cliente_and_chat.json
│    │       │      │    └── 🛠️ interface.json
│    │       │      ├── 📁 ui/
│    │       │      │    └── ✨ new_cliente_and_chat.ui
│    │       │      │    └── ✨ new_interface.ui
│    │       ├── 📁 JsonStyle/
│    │       │      └── 🛠️ style.json
│    │       ├── 📁 logs/
│    │       │      └── 🔍 custom_widgets.log
│    │       ├── 📁 Qss/
│    │       │      ├── 📁 icons/
│    │       │      │    └── 📦 _icons.qrc
│    │       │      │    ├── 📁 icons/
│    │       │      │    │   ├── 📁 feather/
│    │       │      │    │   │   └── 🖼️ icons.png
│    │       │      │    │   ├── 📁 font_awesome/
│    │       │      │    │   │      └── 🖼️ icons.png
│    │       │      │    │   ├── 📁 material_design/
│    │       │      │    │   │      └── 🖼️ icons.png
│    │       │      ├── 📁 scss/
│    │       │      │    └── ✂️ _styles.scss
│    │       │      │    └── ✂️ _variables.scss
│    │       │      │    └── ✂️ defaultStyle.scss
│    │       │      │    └── ✂️ main.scss
│    │       ├── 📁 src_/
│    │       │    └── 🐍 icons_interpreter.py
│    │       │    └── 🐍 ui_interface.py
│    │       ├── 📁 ui/
│    │       │    └── 🎨 interface.ui
│    │       │
│    │       ├── 🐍 Convert.py
│    │       ├── 🐍 main.py
│    │       ├── 🐍 Process.py 
📁 CoreApp/
│    ├── 📁Agents/
│    │       ├── 📁 Company_CEO/
│    │       │    └── 🐍 AI_ByteManager_Company_CEO.py
│    │       │
│    │       ├── 📁 Company_Managers/
│    │       │     └── 🐍 AI_MatrixMinder_Company_Managers.py
│    │       │
│    │       ├── 📁 Pre_Project/
│    │       │    └── 🐍 AI_Tigrao_Pre_Project.py
│    │       │
│    │       ├── 📁 Software_Development/
│    │       │    └── 🐍 AI_DataWeaver_Software_Development.py
│    │       │    └── 🐍 AI_NexGenCoder_Software_Development.py
│    │       │    └── 🐍 AI_QuantumCore_Software_Development.py
│    │       │    └── 🐍 AI_SignalMaster_Software_Development.py
│    │       │
│    │       ├── 📁 Software_Documentation/
│    │       │    ├── 📁 DocGitHubData/
│    │       │    │       └── 📑READMEALLDATA.md
│    │       │    │
│    │       │    └── 🐍 AI_CloudArchitect_Software_Documentation.py
│    │       │    └── 📑docs_uploaded.log
│    │       │
│    │       ├── 📁 Software_Planning/
│    │       │    └── 🐍 AI_Bob_Software_Planning.py
│    │       │    └── 🐍 AI_Dallas_Software_Planning.py
│    │       │
│    │       ├── 📁 Software_Requirements_Analysis/
│    │       │    └── 🐍 AI_SynthOperator_Software_Requirements_Analysis.py
│    │       │
│    │
│    ├── 📁 KeysFirebase/
│    │    └── 🐍 keys.py
│    │
│    ├── 📁 KeysGitHub/
│    │    └── 🐍 keys.py
│    │
│    ├── 📁 KeysOpenAI/
│    │    └── 🐍 keys.py
│    │
│    ├── 📁 SoftwareAI/
│    │       ├── 📁 Functions/
│    │       │    └── 🐍 _init_functions_.py
│    │       │    └── 🐍 add_project_map_function.py
│    │       │    └── 🐍 analyze_file_function.py
│    │       │    └── 🐍 create_github_function.py
│    │       │    └── 🐍 execute_python_code_function.py
│    │       │    └── 🐍 get_datetime_function.py
│    │       │    └── 🐍 improve_code_function.py
│    │       │    └── 🐍 review_pr_function.py
│    │       │    └── 🐍 run_testes_function.py
│    │       │    └── 🐍 save_code_function.py
│    │       │    └── 🐍 save_TXT_function.py
│    │       │    └── 🐍 update_readme_function.py
│    │       │
│    │       ├── 📁 Functions_Submit_Outputs/
│    │       │    └── 🐍 _init_submit_outputs_.py
│    │       │    └── 🐍 add_project_map_submit_outputs.py
│    │       │    └── 🐍 analyze_file_outputs.py
│    │       │    └── 🐍 create_github_repo_and_upload_submit_outputs.py
│    │       │    └── 🐍 execute_python_code_outputs.py
│    │       │    └── 🐍 get_current_datetime_submit_outputs.py
│    │       │    └── 🐍 improve_code_and_create_pull_request_submit_outputs.py
│    │       │    └── 🐍 save_code_outputs.py
│    │       │    └── 🐍 save_TXT_outputs.py
│    │       │    └── 🐍 test_software_submit_outputs.py
│    │       │    └── 🐍 update_readme_outputs.py
│    │       │
│    │       ├── 📁 Instructions/
│    │       │       └── 🐍 _init_Instructions_.py
│    │       │       │
│    │       │       ├── 📁 Company_CEO/
│    │       │       │    └── 🐍 ByteManager.py
│    │       │       │
│    │       │       ├── 📁 Company_Managers/
│    │       │       │     └── 🐍 MatrixMinder.py
│    │       │       │
│    │       │       ├── 📁 Pre_Project/
│    │       │       │    └── 🐍 Tigrao.py
│    │       │       │
│    │       │       ├── 📁 Software_Development/
│    │       │       │    └── 🐍 DataWeaver.py
│    │       │       │    └── 🐍 NexGenCoder.py
│    │       │       │    └── 🐍 QuantumCore.py
│    │       │       │    └── 🐍 SignalMaster.py
│    │       │       │
│    │       │       ├── 📁 Software_Documentation/
│    │       │       │    └── 🐍 CloudArchitect.py
│    │       │       │
│    │       │       ├── 📁 Software_Planning/
│    │       │       │    └── 🐍 Bob.py
│    │       │       │    └── 🐍 Dallas.py
│    │       │       │
│    │       │       ├── 📁 Software_Requirements_Analysis/
│    │       │       │    └── 🐍 SynthOperator.py
│    │       │       │
│    │       │       │
│    │       ├── 📁 Tools/
│    │       │       └── 🐍 _init_tools_.py
│    │       │       │
│    │       │       ├── 📁 Company_CEO/
│    │       │       │    └── 🐍 ByteManager_tools.py
│    │       │       │
│    │       │       ├── 📁 Company_Managers/
│    │       │       │     └── 🐍 MatrixMinder_tools.py
│    │       │       │
│    │       │       ├── 📁 Pre_Project/
│    │       │       │    └── 🐍 Tigrao_tools.py
│    │       │       │
│    │       │       ├── 📁 Software_Development/
│    │       │       │    └── 🐍 DataWeaver_tools.py
│    │       │       │    └── 🐍 NexGenCoder_tools.py
│    │       │       │    └── 🐍 QuantumCore_tools.py
│    │       │       │    └── 🐍 SignalMaster_tools.py
│    │       │       │
│    │       │       ├── 📁 Software_Documentation/
│    │       │       │    └── 🐍 CloudArchitect_tools.py
│    │       │       │
│    │       │       ├── 📁 Software_Planning/
│    │       │       │    └── 🐍 Bob_tools.py
│    │       │       │    └── 🐍 Dallas_tools.py
│    │       │       │
│    │       │       ├── 📁 Software_Requirements_Analysis/
│    │       │       │    └── 🐍 SynthOperator_tools.py
│    │       │       
│    │       └── 🐍 Core.py
│    │       │
│    ├── 📁 Work_Environment/
│    │       ├── 📁 Project-name/
│    │       │       │── 📁 Create_Cronograma_e_planilha_Projeto/
│    │       │       │     └── 📖 documento_cronograma_do_projeto.txt
│    │       │       │     └── 📖 documento_planilha_do_projeto.txt
│    │       │       │
│    │       │       │── 📁 Create_doc_Pre_Projeto/
│    │       │       │     └── 📖 documento_pre_projeto.txt
│    │       │       │
│    │       │       │── 📁 Create_documentation/
│    │       │       │    └── 🗺️ README.md
│    │       │       │
│    │       │       │── 📁 Create_Roadmap_Projeto/
│    │       │       │    └── 📖 documento_Roadmap_do_projeto.txt
│    │       │       │
│    │       │       │── 📁 Software_Development/
│    │       │       │    └── 🐍 python_software.py
│    │       │       │    └── 📖 python_software.txt
│    │       │       │
│    │       │       │── 📁 Software_Requirements_Analysis/
│    │       │       │    └── 📖 analise.txt
│    └── 🐍 _init_agents_.py
│    └── 🐍 _init_core_.py
│    └── 🐍 _init_keys_.py
│    └── 🐍 _init_libs_.py
│    └── 🐍 _init_paths_.py
│    └── 🔧 environment.env
│
└── 🐍 Youscript.py

```